# Aliyun Qwen

It is recommended to use the `qwen-plus-latest` model.

Reference configuration:

- Translation Service: `qwen-plus-latest`
- Base URL: keep default
- API key: your API key
- Timeout (seconds): 500
- Temperature: 0.0
- Send temperature: True
- Enable JSON mode: True

For rate limiting, use Custom mode:
- QPS: 30 or 40
- Pool Max Workers: 1000